dfvfs.compression package
=========================

Submodules
----------

dfvfs.compression.bzip2\_decompressor module
--------------------------------------------

.. automodule:: dfvfs.compression.bzip2_decompressor
   :members:
   :undoc-members:
   :show-inheritance:

dfvfs.compression.decompressor module
-------------------------------------

.. automodule:: dfvfs.compression.decompressor
   :members:
   :undoc-members:
   :show-inheritance:

dfvfs.compression.manager module
--------------------------------

.. automodule:: dfvfs.compression.manager
   :members:
   :undoc-members:
   :show-inheritance:

dfvfs.compression.xz\_decompressor module
-----------------------------------------

.. automodule:: dfvfs.compression.xz_decompressor
   :members:
   :undoc-members:
   :show-inheritance:

dfvfs.compression.zlib\_decompressor module
-------------------------------------------

.. automodule:: dfvfs.compression.zlib_decompressor
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dfvfs.compression
   :members:
   :undoc-members:
   :show-inheritance:
